<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=uk
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'Плагін виводить довідку про систему управління при першому вході користувача до адміністративної частини.',
	'compagnon_nom' => 'Помічник (Companion)',
	'compagnon_slogan' => 'Допомога на початку роботи зі SPIP',
];
